@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 from Quaternion import Quaternion
 
-__revision__ = "$Id: EPS.py 71 2005-12-04 20:08:21Z const $"
+__revision__ = "$Id: EPS.py 87 2006-03-12 20:00:13Z const $"
 
 class EPS(list):
 
@@ -17,23 +17,25 @@ class EPS(list):
 
     def append(self, **kwargs):
         for k, v in kwargs.items():
-            if not hasattr(v, "__iter__"):
-                v = v,
-            list.append(self, "%s%s\n" % (
-                str.join("", ("%s\t" % x for x in v)), k,
+            try:
+                v = iter(v)
+            except TypeError:
+                v = (v,)
+            list.append(self, "%s\t%s\n" % (
+                str.join("\t", (str(x) for x in v)), k,
                 ))
 
     def stroke(self, L, **kwargs):
         list.append(self, "gsave\n")
         list.append(self, "newpath\n")
         self.append(**kwargs)
-        list.append(self, "%g\t%g\tmoveto\n" % (L.zero[0], L.zero[1]))
-        self.extend("%g\t%g\tlineto\n" % (q[0], q[1]) for q in L)
+        list.append(self, "%g\t%g\tmoveto\n" % (L.zero[1], L.zero[2]))
+        self.extend("%g\t%g\tlineto\n" % (q[1], q[2]) for q in L)
         if self.__bbox is None:
             self.__bbox = L.bounds
         else:
             for z in L.bounds:
-                self.__bbox = z & self.__bbox[0], z | self.__bbox[1]
+                self.__bbox = (self.__bbox[0] & z, self.__bbox[1] | z)
         list.append(self, "stroke\n")
         list.append(self, "grestore\n")
 
@@ -41,8 +43,8 @@ class EPS(list):
         if self.__bbox is None:
             bbox = 0, 0, 0, 0
         else:
-            bbox = (self.__bbox[0][0], self.__bbox[0][1],
-                    self.__bbox[1][0], self.__bbox[1][1])
+            bbox = (self.__bbox[0][1], self.__bbox[0][2],
+                    self.__bbox[1][1], self.__bbox[1][2])
         f.write("%!PS-Adobe-3.0 EPSF 3.0\n")
         f.write("%%%%Creator: %s\n" % __name__)
         f.write("%%%%Title: %s\n" % self.__prop["title"])
